@@ -81,7 +81,7 @@ class GBMFitter:
         if not skip_LGB:
             self._fit('LGB', X, y, categorical, feature_selection, early_stopping)
 
-    def _fit(self, library, X, y, categorical=None, feature_selection=-1, early_stopping=None):
+    def _fit(self, library, X, y, categorical=None, feature_selection=-1, num_boost_rounds=5000, early_stopping=None):
         """ Fits data into the algorithms. Generates a model per fold, and stores a
         tuple of (model, rounder) into self.models for each fold.
 
@@ -91,7 +91,10 @@ class GBMFitter:
             - y: target variable
             - categorical: a list of categorical variables
             - folds: Number of folds for CV
-            - feature_selection: the threshold to select features. If -1, takes all"""
+            - feature_selection: the threshold to select features. If -1, takes all
+            - num_boost_rounds: Default boosting rounds
+            - early_stopping: Default early_stopping
+        """
 
         if not self.training_data[library]:
             return
@@ -119,6 +122,7 @@ class GBMFitter:
                                                     train=(X_data.iloc[train_index], y.iloc[train_index]),
                                                     validation=(X_data.iloc[val_index], y.iloc[val_index]),
                                                     categorical=categorical,
+                                                    num_boost_rounds=num_boost_rounds,
                                                     early_stopping=early_stopping)
                 # Print CV metric
                 for metric in self.metrics:
@@ -136,7 +140,7 @@ class GBMFitter:
             else:
                 self._train(library, model, X_data, y, categorical)  # TODO to be tested
 
-    def _train(self, library, model_data, train, validation=None, categorical=[], early_stopping=None):
+    def _train(self, library, model_data, train, validation=None, categorical=[], num_boost_rounds=5000, early_stopping=None):
         """ Trains a mode on training data, calculates predictions for training and for validation,
         and also creates and fits the corresponding OptRounder object.
 
@@ -146,6 +150,8 @@ class GBMFitter:
             - train: Tuple with train data, train[0] is X and train[1] is y
             - validation: Validation data, validation[0] is X and validation[1] is y
             - categorical: List with the categorical variables
+            - num_boost_rounds: Default boosting rounds. Could be overriden by individual values in model_data['n]
+            - early_stopping: Default early_stopping. Could be overriden by individual values in model_data['es']
             """
 
         # Get train and validation sets
@@ -160,8 +166,8 @@ class GBMFitter:
             rounder = OptRounder()
 
         obj = model_data['obj'] if 'obj' in model_data else None  # Objective function
-        num_boost_rounds = model_data['n'] if 'n' in model_data else 5000  # Num rounds
-        early_stopping = model_data['es'] if 'es' in model_data else None  # Early Stopping
+        num_boost_rounds = model_data['n'] if 'n' in model_data else num_boost_rounds  # Num rounds
+        early_stopping = model_data['es'] if 'es' in model_data else early_stopping  # Early Stopping
 
         # Train and predict train and validation sets
         if library == 'CB':
